@@ -1,7 +1,9 @@
 package Color::RGB::Util;
 
-our $DATE = '2019-08-20'; # DATE
-our $VERSION = '0.599'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-06-07'; # DATE
+our $DIST = 'Color-RGB-Util'; # DIST
+our $VERSION = '0.600'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,6 +17,10 @@ our @EXPORT_OK = qw(
                        assign_rgb_color
                        assign_rgb_dark_color
                        assign_rgb_light_color
+                       hsl2hsv
+                       hsl2rgb
+                       hsv2hsl
+                       hsv2rgb
                        int2rgb
                        mix_2_rgb_colors
                        mix_rgb_colors
@@ -421,6 +427,69 @@ sub rgb2hsv {
     return sprintf("%.3g %.3g %.3g", $h, $s, $v);
 }
 
+sub hsl2hsv {
+    my $hsl = shift;
+
+    my ($h, $s, $l) = split / /, $hsl;
+    my $_h = $h;
+    my $_s;
+    my $_v;
+
+    $l *= 2;
+    $s *= ($l <= 1) ? $l : 2-$l;
+    $_v = ($l+$s) / 2;
+    $_s = (2*$s) / ($l+$s);
+
+    "$_h $_s $_v";
+}
+
+sub hsv2hsl {
+    my $hsv = shift;
+
+    my ($h, $s, $v) = split / /, $hsv;
+    my $_h = $h;
+    my $_s = $s * $v;
+    my $_l = (2-$s) * $v;
+
+    $_s /= $_l <= 1 ? ($_l==0 ? 1 : $_l) : (2-$_l);
+    $_l /= 2;
+
+    "$_h $_s $_l";
+}
+
+sub hsl2rgb {
+    hsv2rgb(hsl2hsv(shift));
+}
+
+sub hsv2rgb {
+    my $hsv = shift;
+
+    my ($h, $s, $v) = split / /, $hsv;
+
+    my $i = int($h/60);
+    my $f = $h/60 - $i;
+    my $p = $v * (1-$s);
+    my $q = $v * (1-$f*$s);
+    my $t = $v * (1-(1-$f)*$s);
+
+    my ($r, $g, $b);
+    if ($i==0) {
+        $r = $v; $g = $t; $b = $p;
+    } elsif ($i==1) {
+        $r = $q; $g = $v; $b = $p;
+    } elsif ($i==2) {
+        $r = $p; $g = $v; $b = $t;
+    } elsif ($i==3) {
+        $r = $p; $g = $q; $b = $v;
+    } elsif ($i==4) {
+        $r = $t; $g = $p; $b = $v;
+    } else {
+        $r = $v; $g = $p; $b = $q;
+    }
+
+    return sprintf("%02x%02x%02x", $r*255, $g*255, $b*255);
+}
+
 1;
 # ABSTRACT: Utilities related to RGB colors
 
@@ -436,7 +505,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.599 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2019-08-20.
+This document describes version 0.600 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2020-06-07.
 
 =head1 SYNOPSIS
 
@@ -535,6 +604,47 @@ dark.
 Like L</assign_rgb_color> except that it will make sure the assigned color is
 light.
 
+=head2 hsl2hsv
+
+Usage:
+
+ my $hsl = hsl2hsv("0 1 0.5"); # => "0 1 1"
+
+Convert HSL to HSV.
+
+=head2 hsl2rgb
+
+Usage:
+
+ my $rgb = hsl2rgb("0 1 0.5"); # => ff0000
+
+Convert HSL to RGB. HSL should be given in a whitespace-separated H,S,L values
+e.g. "0 1 0.5". H (hue degree) has a range from 0-360 where 0 is red, 120 is
+green, 240 is blue and 360 is back to red. S (saturation) has a range from 0-1
+where 0 is gray and 1 is fully saturated hue. L (lumination) has a range from
+0-1 where 0 is fully black, 0.5 fully saturated, and 1 is fully white. See also
+L</rgb2hsl>.
+
+=head2 hsv2hsl
+
+Usage:
+
+ my $hsl = hsv2hsl("0 1 1"); # => "0 1 0.5"
+
+Convert HSV to HSL.
+
+=head2 hsv2rgb
+
+Usage:
+
+ my $rgb = hsv2rgb("0 1 1"); # => ff0000
+
+Convert HSV to RGB. HSV should be given in a whitespace-separated H,S,V values
+e.g. "0 1 1". H (hue degree) has a range from 0-360 where 0 is red, 120 is
+green, 240 is blue and 360 is back to red. S (saturation) has a range from 0-1
+where 0 is gray and 1 is fully saturated hue. V (value) has a range from 0-1
+where 0 is black and 1 is white. See also L</rgb2hsv>.
+
 =head2 int2rgb
 
 Usage:
@@ -636,7 +746,7 @@ Usage:
 
  my $hsv = rgb2hsv($rgb); # example: "0 1 255"
 
-Convert RGB (0-255) to HSV. The result is a space-separated H, S, V values.
+Convert RGB (0-255) to HSV. The result is a space-separated H, S, V values. See
 
 =head2 rgb2int
 
@@ -702,7 +812,7 @@ preferred.
 
 =back
 
-For more details about color difference, refer to
+For more about color difference, try reading
 L<https://en.wikipedia.org/wiki/Color_difference>.
 
 =head2 rgb_distance
@@ -764,7 +874,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Color-RGB-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Color-RGB-Util>.
+Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Color-Util>.
 
 =head1 BUGS
 
@@ -784,7 +894,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
